Struct style::values::generics::rect::Rect
[−]
[src]
pub struct Rect<T>(pub T, pub T, pub T, pub T);
A CSS value made of four components, where its ToCss impl will try to
serialize as few components as possible, like for example in border-width.
Methods
impl<T> Rect<T>[src]
impl<T> Rect<T> where
T: Clone, [src]
T: Clone,
pub fn all(v: T) -> Self[src]
Returns a rect with all the values equal to v.
pub fn parse_with<'i, 't, Parse>(
context: &ParserContext,
input: &mut Parser<'i, 't>,
parse: Parse
) -> Result<Self, ParseError<'i>> where
Parse: Fn(&ParserContext, &mut Parser<'i, 't>) -> Result<T, ParseError<'i>>, [src]
context: &ParserContext,
input: &mut Parser<'i, 't>,
parse: Parse
) -> Result<Self, ParseError<'i>> where
Parse: Fn(&ParserContext, &mut Parser<'i, 't>) -> Result<T, ParseError<'i>>,
Parses a new Rect<T> value with the given parse function.